==> 0.10.5.tar.gz: lib/src/form_builder/textfield_parser.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_neumorphic/flutter_neumorphic.dart';

import 'package:formio_flutter/formio_flutter.dart';
import 'package:formio_flutter/src/abstraction/abstraction.dart';
import 'package:formio_flutter/src/models/models.dart';
import 'package:formio_flutter/src/providers/providers.dart';

/// Extends the abstract class [WidgetParser]
class TextFieldParser extends WidgetParser {
  /// Returns a [Widget] of type [TextField]
  @override
  Widget parse(
    Component map,
    BuildContext context,
    ClickListener listener,
    WidgetProvider widgetProvider,
  ) {
    return TextFieldCreator(map: map, widgetProvider: widgetProvider);
  }

  /// [widgetName] => "textfield"
  @override
  String get widgetName => 'textfield';
}

// ignore: must_be_immutable
class TextFieldCreator extends StatefulWidget implements Manager {
  TextFieldCreator({this.map, this.widgetProvider});

  final Component map;
  final WidgetProvider widgetProvider;
  final controller = TextEditingController();

  @override
  _TextFieldCreatorState createState() => _TextFieldCreatorState();

  /// Returns a [String] with the value contained inside [Component.key]
  @override
  String get keyValue => map.key ?? 'textField';

  /// Current value of the [Widget]
  @override
  String get data => controller.text ?? '';
}

class _TextFieldCreatorState extends State<TextFieldCreator> {
  String characters = '';
  String _calculate = '';
  List<String> _keys = [];
  List<String> _operators = [];
  final Map<String, dynamic> _mapper = {};

  @override
  void initState() {
    super.initState();

    _mapper[widget.map.key] = {''};

    if (widget.map.defaultValue != null) {
      (widget.map.defaultValue is List<String>)
          ? widget.controller.text = widget.map.defaultValue
              .asMap()
              .values
              .toString()
              .replaceAll(RegExp('[()]'), '')
          : widget.controller.text = widget.map.defaultValue.toString();
    }

    widget.controller.addListener(() {
      _mapper.update(widget.map.key, (value) => widget.controller.value.text);
    });

    WidgetsBinding.instance.addPostFrameCallback((_) {
      _mapper.update(widget.map.key, (value) => widget.controller.value.text);
      widget.widgetProvider.widgetBloc.registerMap(_mapper);
    });
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    bool isVisible = true;
    final size = MediaQuery.of(context).size;
    if (widget.map.calculateValue != null) {
      _keys = parseListStringCalculated(widget.map.calculateValue);
      _operators = parseListStringOperator(widget.map.calculateValue);
    }

    return StreamBuilder(
      stream: widget.widgetProvider.widgetBloc.widgetsStream,
      builder: (context, AsyncSnapshot<Map<String, dynamic>> snapshot) {
        isVisible = (widget.map.conditional != null && snapshot.data != null)
            ? (snapshot.data.containsKey(widget.map.conditional.when) &&
                    snapshot.data[widget.map.conditional.when].toString() ==
                        widget.map.conditional.eq)
                ? widget.map.conditional.show
                : !widget.map.conditional.show
            : true;
        if (widget.map.calculateValue != null &&
            widget.map.calculateValue.isNotEmpty &&
            snapshot.data != null) {
          _calculate = "";
          _keys.asMap().forEach((value, element) {
            _calculate = (snapshot.data.containsKey(element))
                ? "$_calculate ${snapshot.data[element]} ${(value < _operators.length) ? (_operators[value]) : ""}"
                : double.tryParse(element) != null
                    ? "$_calculate $element ${(value < _operators.length) ? (_operators[value]) : ""}"
                    : "$_calculate 0 ${(value < _operators.length) ? (_operators[value]) : ""}";
          });
          widget.controller.text = parseCalculate(_calculate);
        }
        if (!isVisible) widget.controller.text = "";
        return (!isVisible)
            ? SizedBox.shrink()
            : (widget.map.total != 0)
                ? Neumorphic(
                    margin: EdgeInsets.symmetric(horizontal: 16, vertical: 12),
                    padding: EdgeInsets.symmetric(horizontal: 12, vertical: 6),
                    style: NeumorphicStyle(
                      boxShape: NeumorphicBoxShape.roundRect(
                          BorderRadius.circular(12)),
                    ),
                    child: Container(
                      //width: (size.width * (1 / (widget.map.total + 0.5))),
                      width: (size.width * 0.5),
                      padding: EdgeInsets.symmetric(horizontal: 4.0),
                      child: TextField(
                        enabled: !widget.map.disabled,
                        obscureText: widget.map.mask,
                        keyboardType: parsetInputType(widget.map.type),
                        style: TextStyle(
                          fontSize: 20.0,
                          color: Colors.black,
                        ),
                        controller: widget.controller,
                        onChanged: (value) {
                          _mapper.update(widget.map.key, (nVal) => value);
                          widget.widgetProvider.widgetBloc.registerMap(_mapper);
                          setState(() => characters = value);
                        },
                        decoration: InputDecoration(
                          counter: (widget.map.showWordCount != null &&
                                  widget.map.showWordCount)
                              ? (characters != "")
                                  ? Text(
                                      '${characters.split(' ').length} words')
                                  : Container()
                              : null,
                          prefixText: (widget.map.prefix != null)
                              ? widget.map.prefix
                              : "",
                          prefixStyle: TextStyle(
                            background: Paint()..color = Colors.teal[200],
                            color: Colors.black,
                            fontWeight: FontWeight.w600,
                            fontSize: 20.0,
                          ),
                          labelText: (widget.map.label != null)
                              ? widget.map.label
                              : "",
                          hintText: widget.map.label,
                          suffixText: (widget.map.suffix != null)
                              ? widget.map.suffix
                              : "",
                          suffixStyle: TextStyle(
                            background: Paint()..color = Colors.teal[200],
                            color: Colors.black,
                            fontWeight: FontWeight.w600,
                            fontSize: 20.0,
                          ),
                        ),
                      ),
                    ),
                  )
                : Neumorphic(
                    margin: EdgeInsets.symmetric(horizontal: 16, vertical: 12),
                    padding: EdgeInsets.symmetric(horizontal: 12, vertical: 6),
                    style: NeumorphicStyle(
                      boxShape: NeumorphicBoxShape.roundRect(
                          BorderRadius.circular(12)),
                    ),
                    child: TextField(
                      enabled: !widget.map.disabled,
                      obscureText: widget.map.mask,
                      keyboardType: parsetInputType(widget.map.type),
                      style: TextStyle(
                        fontSize: 20.0,
                        color: Colors.black,
                      ),
                      controller: widget.controller,
                      onChanged: (value) {
                        _mapper.update(widget.map.key, (nVal) => value);
                        widget.widgetProvider.widgetBloc.registerMap(_mapper);
                        setState(() => characters = value);
                      },
                      decoration: InputDecoration(
                        counter: (widget.map.showWordCount != null &&
                                widget.map.showWordCount)
                            ? (characters != "")
                                ? Text('${characters.split(' ').length} words')
                                : Container()
                            : null,
                        prefixText: (widget.map.prefix != null)
                            ? widget.map.prefix
                            : "",
                        prefixStyle: TextStyle(
                          background: Paint()..color = Colors.teal[200],
                          color: Colors.black,
                          fontWeight: FontWeight.w600,
                          fontSize: 20.0,
                        ),
                        labelText:
                            (widget.map.label != null) ? widget.map.label : "",
                        hintText: widget.map.label,
                        suffixText: (widget.map.suffix != null)
                            ? widget.map.suffix
                            : "",
                        suffixStyle: TextStyle(
                          background: Paint()..color = Colors.teal[200],
                          color: Colors.black,
                          fontWeight: FontWeight.w600,
                          fontSize: 20.0,
                        ),
                      ),
                    ),
                  );
      },
    );
  }
}

==> 0.10.7.tar.gz: lib/src/form_builder/textfield_parser.dart <==
import 'package:flutter/material.dart';

import 'package:formio_flutter/formio_flutter.dart';
import 'package:formio_flutter/src/abstraction/abstraction.dart';
import 'package:formio_flutter/src/models/models.dart';
import 'package:formio_flutter/src/providers/providers.dart';

/// Extends the abstract class [WidgetParser]
class TextFieldParser extends WidgetParser {
  /// Returns a [Widget] of type [TextField]
  @override
  Widget parse(
    Component map,
    BuildContext context,
    ClickListener listener,
    WidgetProvider widgetProvider,
  ) {
    return TextFieldCreator(map: map, widgetProvider: widgetProvider);
  }

  /// [widgetName] => "textfield"
  @override
  String get widgetName => 'textfield';
}

// ignore: must_be_immutable
class TextFieldCreator extends StatefulWidget implements Manager {
  TextFieldCreator({this.map, this.widgetProvider});

  final Component map;
  final WidgetProvider widgetProvider;
  final controller = TextEditingController();

  @override
  _TextFieldCreatorState createState() => _TextFieldCreatorState();

  /// Returns a [String] with the value contained inside [Component.key]
  @override
  String get keyValue => map.key ?? 'textField';

  /// Current value of the [Widget]
  @override
  String get data => controller.text ?? '';
}

class _TextFieldCreatorState extends State<TextFieldCreator> {
  String characters = '';
  String _calculate = '';
  List<String> _keys = [];
  List<String> _operators = [];
  final Map<String, dynamic> _mapper = {};

  @override
  void initState() {
    super.initState();

    _mapper[widget.map.key] = {''};

    if (widget.map.defaultValue != null) {
      (widget.map.defaultValue is List<String>)
          ? widget.controller.text = widget.map.defaultValue
              .asMap()
              .values
              .toString()
              .replaceAll(RegExp('[()]'), '')
          : widget.controller.text = widget.map.defaultValue.toString();
    }

    widget.controller.addListener(() {
      _mapper.update(widget.map.key, (value) => widget.controller.value.text);
    });

    WidgetsBinding.instance.addPostFrameCallback((_) {
      _mapper.update(widget.map.key, (value) => widget.controller.value.text);
      widget.widgetProvider.widgetBloc.registerMap(_mapper);
    });
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    var isVisible = true;
    final size = MediaQuery.of(context).size;

    if (widget.map.calculateValue != null) {
      _keys = parseListStringCalculated(widget.map.calculateValue);
      _operators = parseListStringOperator(widget.map.calculateValue);
    }

    return StreamBuilder(
      stream: widget.widgetProvider.widgetBloc.widgetsStream,
      builder: (context, AsyncSnapshot<Map<String, dynamic>> snapshot) {
        isVisible = (widget.map.conditional != null && snapshot.data != null)
            ? (snapshot.data.containsKey(widget.map.conditional.when) &&
                    snapshot.data[widget.map.conditional.when].toString() ==
                        widget.map.conditional.eq)
                ? widget.map.conditional.show
                : !widget.map.conditional.show
            : true;
        if (widget.map.calculateValue != null &&
            widget.map.calculateValue.isNotEmpty &&
            snapshot.data != null) {
          _calculate = "";
          _keys.asMap().forEach((value, element) {
            _calculate = (snapshot.data.containsKey(element))
                ? "$_calculate ${snapshot.data[element]} ${(value < _operators.length) ? (_operators[value]) : ""}"
                : double.tryParse(element) != null
                    ? "$_calculate $element ${(value < _operators.length) ? (_operators[value]) : ""}"
                    : "$_calculate 0 ${(value < _operators.length) ? (_operators[value]) : ""}";
          });
          widget.controller.text = parseCalculate(_calculate);
        }
        if (!isVisible) widget.controller.text = "";
        return (!isVisible)
            ? SizedBox.shrink()
            : (widget.map.total != 0)
                ? Container(
                    //width: (size.width * (1 / (widget.map.total + 0.5))),
                    width: (size.width * 0.5),
                    padding: EdgeInsets.symmetric(horizontal: 4.0),
                    child: TextField(
                      enabled: !widget.map.disabled,
                      obscureText: widget.map.mask,
                      keyboardType: parsetInputType(widget.map.type),
                      style: TextStyle(
                        fontSize: 20.0,
                        color: Colors.black,
                      ),
                      controller: widget.controller,
                      onChanged: (value) {
                        _mapper.update(widget.map.key, (nVal) => value);
                        widget.widgetProvider.widgetBloc.registerMap(_mapper);
                        setState(() => characters = value);
                      },
                      decoration: InputDecoration(
                        counter: (widget.map.showWordCount != null &&
                                widget.map.showWordCount)
                            ? (characters != "")
                                ? Text('${characters.split(' ').length} words')
                                : Container()
                            : null,
                        prefixText: (widget.map.prefix != null)
                            ? widget.map.prefix
                            : "",
                        prefixStyle: TextStyle(
                          background: Paint()..color = Colors.teal[200],
                          color: Colors.black,
                          fontWeight: FontWeight.w600,
                          fontSize: 20.0,
                        ),
                        labelText:
                            (widget.map.label != null) ? widget.map.label : "",
                        hintText: widget.map.label,
                        suffixText: (widget.map.suffix != null)
                            ? widget.map.suffix
                            : "",
                        suffixStyle: TextStyle(
                          background: Paint()..color = Colors.teal[200],
                          color: Colors.black,
                          fontWeight: FontWeight.w600,
                          fontSize: 20.0,
                        ),
                      ),
                    ),
                  )
                : TextField(
                    enabled: !widget.map.disabled,
                    obscureText: widget.map.mask,
                    keyboardType: parsetInputType(widget.map.type),
                    style: TextStyle(
                      fontSize: 20.0,
                      color: Colors.black,
                    ),
                    controller: widget.controller,
                    onChanged: (value) {
                      _mapper.update(widget.map.key, (nVal) => value);
                      widget.widgetProvider.widgetBloc.registerMap(_mapper);
                      setState(() => characters = value);
                    },
                    decoration: InputDecoration(
                      counter: (widget.map.showWordCount != null &&
                              widget.map.showWordCount)
                          ? (characters != "")
                              ? Text('${characters.split(' ').length} words')
                              : Container()
                          : null,
                      prefixText:
                          (widget.map.prefix != null) ? widget.map.prefix : "",
                      prefixStyle: TextStyle(
                        background: Paint()..color = Colors.teal[200],
                        color: Colors.black,
                        fontWeight: FontWeight.w600,
                        fontSize: 20.0,
                      ),
                      labelText:
                          (widget.map.label != null) ? widget.map.label : "",
                      hintText: widget.map.label,
                      suffixText:
                          (widget.map.suffix != null) ? widget.map.suffix : "",
                      suffixStyle: TextStyle(
                        background: Paint()..color = Colors.teal[200],
                        color: Colors.black,
                        fontWeight: FontWeight.w600,
                        fontSize: 20.0,
                      ),
                    ),
                  );
      },
    );
  }
}
